#
# spec file for package python-boto3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-boto3
Version:        1.5.1
Release:        lp150.1.3
Url:            https://github.com/boto/boto3
Summary:        Amazon Web Services Library
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/b/boto3/boto3-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-botocore < 1.9.0
Requires:       python-botocore >= 1.8.0
%ifpython2
Requires:       python2-futures
BuildRequires:  python2-futures
%endif
Requires:       python-jmespath < 1.0.0
Requires:       python-jmespath >= 0.7.1
Requires:       python-s3transfer < 0.2.0
Requires:       python-s3transfer >= 0.1.10
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Boto3 is the Amazon Web Services (AWS) Software Development Kit (SDK) for
Python, which allows Python developers to write software that makes use of
services like Amazon S3 and Amazon EC2.

For documentation consult the online documentation at
http://boto3.readthedocs.org/en/latest/

# Note to maintainers also familia with python-boto:
# The documentation generation requires access to AWS, thus it is not
# possible to generate the documentation in OBS

%prep
%setup -q -n boto3-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%doc CONTRIBUTING.rst LICENSE README.rst 
%{python_sitelib}/*

%changelog
* Sat Dec 16 2017 arun@gmx.de
- update to version 1.5.1:
  * api-change:appstream: [botocore] Update appstream client to latest
    version
- changes from version 1.5.0:
  * bugfix:Filters: Fixes a bug where parameters passed to resource
    collections could be mutated after the collections were created.
  * api-change:ses: [botocore] Update ses client to latest version
  * enhancement:credentials: [botocore] Moved the JSONFileCache from
    the CLI into botocore so that it can be used without importing
    from the cli.
  * feature:botocore dependency: Update dependency strategy to always
    take a floor on the most recent version of botocore. This means
    whenever there is a release of botocore, boto3 will release as
    well to account for the new version of botocore.
  * api-change:apigateway: [botocore] Update apigateway client to
    latest version
* Thu Dec  7 2017 arun@gmx.de
- specfile:
  * updated version for botocore
- update to version 1.4.8:
  * enhancement:botocore: Raised minor version dependency for botocore
* Fri Nov 24 2017 mpluskal@suse.com
- Require futures package only for python2 (boo#1069697)
* Thu Sep 14 2017 rjschwei@suse.com
- Update to version 1.4.7
  + botocore: Raised minor version dependency for botocore
- From 1.4.6
  + Logging: Switch log levels from INFO to DEBUG (#1208)
- From 1.4.5
  + s3: Add a LifecycleConfiguration resource to resolve issues with the
    existing Lifecycle resource.
* Thu May 11 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update source URL.
- Update to version 1.4.4
  * feature:``s3``: Add ability to disable thread use with ``use_threads`` option
  * bugfix:Resource: Fix resource hashing.
* Wed Jan 18 2017 astieger@suse.com
- fetch upstream sources to fix Factory submission
* Thu Dec 15 2016 rjschwei@suse.com
- Update to version 1.4.2 (bsc#1015776)
  + feature:ec2: Update client to latest version
* Wed Oct 26 2016 rjschwei@suse.com
- Fix the version requirement for botocore to ensure proper functioning of
  the API
* Wed Oct 26 2016 rjschwei@suse.com
- Add missing dependency on python-s3transfer
* Tue Oct 25 2016 rjschwei@suse.com
- Update to version 1.4.1 (bsc#1007084)
  + feature:Session: Expose available_profiles property for Session
    (``#704 <https://github.com/boto/boto3/issues/704>`__)
  + bugfix:s3: Fix issue when transfers would not exit quickly from signals
  + bugfix:sqs.Queue: Fix issue in DeadLetterSourceQueues collection
- From 1.4.0
  + feature:DynamoDB: Add request auto de-duplication based on specified
    primary keys for batch_writer. (#605)
  + feature:s3: Add managed file-like object uploads to S3 client, Bucket,
    and Object.
  + bugfix:Session: Fixed Session.__repr__ region argument name.
  + feature:s3: Add managed copies to S3 client, Bucket, and Object.
  + feature:s3: Add managed downloads to file-like objects in the S3 client,
    Bucket, and Object.
  + bugfix:s3: Port s3.transfer module to use s3transfer package. Please
    refer to Upgrading Notes when upgrading. In porting the logic over,
    various performance issues and bugs were fixed.
  + feature:s3: Add io_chunksize parameter to TransferConfig
* Mon Jun  6 2016 dmueller@suse.com
- fix source url
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to 1.3.1
  + feature:S3: Add custom load to ObjectSummary
  + feature:Session: Add method to get session credentials
  + bugfix:DynamoDB: Ensure batch writer never sends more than flush_amount (#483)
  + feature:Resources: Add get_available_subresources to Resources (#113)
* Fri Apr  8 2016 rjschwei@suse.com
- Fix version requirement for botocore
* Fri Apr  8 2016 rjschwei@suse.com
- Update to version 1.3.0 (bsc#974705)
  + feature:Session: Add get_available_partitions and get_available_regions
    methods to determine partitions and a service's available regions.
  + feature:EC2: Update resource model to include Route resources. (issue 532)
- From 1.2.6 - (2016-03-01)
  + bugfix:Resources: Properly alias identifiers which are also in the shape.
- From 1.2.5 - (2016-02-25)
  + bugfix:S3: Forward extra_args when using multipart downloads. (issue 503)
- From 1.2.4 - (2016-02-18)
  + feature:EC2: Add delete_tags() action to Instance resource. (issue 459)
  + feature:Session: Add region_name property on session. (issue 414)
  + bugfix:S3: Fix issue with hanging downloads. (issue 471)
* Tue Feb  2 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#320335,bsc#962170)
* Tue Jan 19 2016 rjschwei@suse.com
- Fix license string
* Fri Jan 15 2016 rjschwei@suse.com
- Initial build
  + Version 1.2.3
